@@ -1,7 +1,7 @@
 package Weed::BaseNode;
 use Weed;
 
-our $VERSION = '0.012';
+our $VERSION = '0.015';
 
 use Weed::Parse::FieldDescription;
 
@@ -9,7 +9,19 @@ sub SET_DESCRIPTION {
 	my ( $this, $description ) = @_;
 	my $fieldDescriptions = Weed::Parse::FieldDescription::parse @{ $description->{body} };
 	my $fieldDefinitions = [ map { new X3DFieldDefinition(@$_) } @$fieldDescriptions ];
+	$this->setFieldDefinitions($fieldDefinitions);
+}
+
+sub setFieldDefinitions {
+	my ( $this, $fieldDefinitions ) = @_;
+	my $package = $this->X3DPackage::getName;
+
 	$this->X3DPackage::Scalar("X3DFieldDefinitions") = $fieldDefinitions;
+
+	$package->X3DPackage::Glob( $_->getName ) = $_->createFieldClosure($package)
+	  foreach @$fieldDefinitions;
+
+	return;
 }
 
 use Weed 'X3DBaseNode : X3DObject { }';
@@ -20,7 +32,7 @@ sub new {
 
 	$this->setName($name);
 
-	$this->setFields( new X3DFieldSet( scalar $this->getFieldDefinitions, $this ) );
+	$this->setFields( new X3DFieldSet( $this->getFieldDefinitions, $this ) );
 
 	return $this;
 }
@@ -29,8 +41,8 @@ sub getClone {
 	my $this = shift;
 	my $copy = $this->new( $this->getName );
 
-	$copy->{fields}->{$_}->setValue( $this->getField($_) )
-	  foreach map { $_->getName } $this->getFieldDefinitions;
+	$copy->getField( $_->getName )->setValue( $_->getValue )
+	  foreach @{ $this->getFields };
 
 	return $copy;
 }
@@ -46,13 +58,9 @@ sub getName { $_[0]->{name}->toString }
 sub setFields { $_[0]->{fields} = $_[1] }
 sub getFields { $_[0]->{fields} }
 
-sub getField { $_[0]->{fields}->getField( $_[1], $_[0] ) }
+sub getField { $_[0]->getFields->getField( $_[1], $_[0] ) }
 
-sub getFieldDefinitions {
-	wantarray ?
-	  @{ $_[0]->X3DPackage::Scalar("X3DFieldDefinitions") } :
-	  $_[0]->X3DPackage::Scalar("X3DFieldDefinitions")
-}
+sub getFieldDefinitions { $_[0]->X3DPackage::Scalar("X3DFieldDefinitions") }
 
 # Basenode
 sub toString {
@@ -83,16 +91,11 @@ sub toString {
 		$string .= X3DGenerator->indent;
 	}
 
-	$string .= $this->{fields};
+	$string .= $this->getFields;
 
 	return $string;
 }
 
-sub dispose {
-	my $this = shift;
-	return;
-}
-
 #sub DESTROY {
 #	my $this = shift;
 #print "BaseNode::DESTROY";
@@ -101,7 +104,34 @@ sub dispose {
 #print  "BaseNode::Clones:  ", $this->{clones};
 #}
 
+sub DESTROY {
+	# X3DMessage->Debug( $_[0] );
+	return;
+}
+
 1;
 __END__
 	#printf "BaseNode::dispose: %s, %d\n", $node->getName, $node->{clones};
 Scalar::Quote 
+
+	print '';
+	print 'wantref: ', Want::wantref() if Want::wantref();
+	print 'VOID'      if Want::want('VOID');
+	print 'SCALAR'    if Want::want('SCALAR');
+	print 'REF'       if Want::want('REF');
+	print 'REFSCALAR' if Want::want('REFSCALAR');
+	print 'CODE'      if Want::want('CODE');
+	print 'HASH'      if Want::want('HASH');
+	print 'ARRAY'     if Want::want('ARRAY');
+	print 'GLOB'      if Want::want('GLOB');
+	print 'OBJECT'    if Want::want('OBJECT');
+	print 'BOOL'      if Want::want('BOOL');
+	print 'LIST'      if Want::want('LIST');
+	print 'COUNT'     if Want::want('COUNT');
+	print 'Infinity'  if Want::want('Infinity');
+	print 'LVALUE'    if Want::want('LVALUE');
+	print 'ASSIGN'    if Want::want('ASSIGN');
+	print 'RVALUE'    if Want::want('RVALUE');
+
+*{"${callpkg}::$sym"} =
+	    $type eq '&' ? \&{"${pkg}::$sym"}
