@@ -1,8 +1,8 @@
 package X3D::Components::Core;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
-#Abstract node types
+#Abstract types
 use X3D::Components::Core::Node;
 use X3D::Components::Core::ChildNode;
 use X3D::Components::Core::BindableNode;
@@ -11,7 +11,9 @@ use X3D::Components::Core::PrototypeInstance;
 use X3D::Components::Core::SensorNode;
 use X3D::Components::Core::InfoNode;
 
-#Node set
+#Node reference
+use X3D::Namespace;
+
 use X3D::Components::Core::Nodes::MetadataDouble;
 use X3D::Components::Core::Nodes::MetadataFloat;
 use X3D::Components::Core::Nodes::MetadataInteger;
@@ -19,5 +21,7 @@ use X3D::Components::Core::Nodes::MetadataSet;
 use X3D::Components::Core::Nodes::MetadataString;
 use X3D::Components::Core::Nodes::WorldInfo;
 
+no X3D::Namespace;
+
 1;
 __END__
